@@ -27,7 +27,7 @@ extension in the `optik_ext` module).
 Quick start: simplest usage
 ---------------------------
 
-.. python ::
+.. ::
 
   >>> import sys
   >>> from logilab.common.configuration import Configuration
@@ -122,7 +122,7 @@ from os.path import exists, expanduser
 from copy import copy
 from warnings import warn
 
-from six import string_types
+from six import integer_types, string_types
 from six.moves import range, configparser as cp, input
 
 from logilab.common.compat import str_encode as _encode
@@ -372,7 +372,7 @@ def format_option_value(optdict, value):
         value = value and 'yes' or 'no'
     elif isinstance(value, string_types) and value.isspace():
         value = "'%s'" % value
-    elif optdict.get('type') == 'time' and isinstance(value, (float, int, long)):
+    elif optdict.get('type') == 'time' and isinstance(value, (float, ) + integer_types):
         value = format_time(value)
     elif optdict.get('type') == 'bytes' and hasattr(value, '__int__'):
         value = format_bytes(value)
@@ -401,6 +401,9 @@ def ini_format(stream, options, encoding):
             print('#%s=' % optname, file=stream)
         else:
             value = _encode(value, encoding).strip()
+            if optdict.get('type') == 'string' and '\n' in value:
+                prefix = '\n    '
+                value = prefix + prefix.join(value.split('\n'))
             print('%s=%s' % (optname, value), file=stream)
 
 format_section = ini_format_section
@@ -635,7 +638,7 @@ class OptionsManagerMixIn(object):
             parser = self.cfgfile_parser
             parser.read([config_file])
             # normalize sections'title
-            for sect, values in parser._sections.items():
+            for sect, values in list(parser._sections.items()):
                 if not sect.isupper() and values:
                     parser._sections[sect.upper()] = values
         elif not self.quiet:
@@ -946,8 +949,8 @@ class ConfigurationMixIn(OptionsManagerMixIn, OptionsProviderMixIn):
         options_by_group = {}
         for optname, optdict in options:
             options_by_group.setdefault(optdict.get('group', self.name.upper()), []).append((optname, optdict))
-        for group, options in options_by_group.items():
-            self.add_option_group(group, None, options, self)
+        for group, group_options in options_by_group.items():
+            self.add_option_group(group, None, group_options, self)
         self.options += tuple(options)
 
     def load_defaults(self):
@@ -1042,7 +1045,7 @@ def read_old_config(newconfig, changes, configfile):
             option, oldtype, newvalue = action[1:]
             changesindex.setdefault(option, []).append((action[0], oldtype, newvalue))
             continue
-        if action[1] in ('added', 'removed'):
+        if action[0] in ('added', 'removed'):
             continue # nothing to do here
         raise Exception('unknown change %s' % action[0])
     # build a config object able to read the old config
