@@ -70,6 +70,8 @@ MANUAL_UNICODE_MAP = {
     u'\xf8': u'o',    # LATIN SMALL LETTER O WITH STROKE
     u'\xbb': u'"',    # RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
     u'\xdf': u'ss',   # LATIN SMALL LETTER SHARP S
+    u'\u2013': u'-',  # HYPHEN
+    u'\u2019': u"'",  # SIMPLE QUOTE
     }
 
 def unormalize(ustring, ignorenonascii=None, substitute=None):
@@ -369,8 +371,8 @@ def apply_units(string, units, inter=None, final=float, blank_reg=_BLANK_RE,
             try:
                 value *= units[unit.lower()]
             except KeyError:
-                raise KeyError('invalid unit %s. valid units are %s' %
-                               (unit, units.keys()))
+                raise ValueError('invalid unit %s. valid units are %s' %
+                                 (unit, list(units.keys())))
         values.append(value)
     return final(sum(values))
 
